@@ -18,17 +18,17 @@ fv.pushLink("frame1", "frame2", color=(1, 0, 0))
 fv.pushFrame(frame3, "frame3")
 fv.deleteFrame("frame3")
 
-fv.createPointsList("a", size=10, color=(1, 0, 0))
+# fv.createPointsList("a", size=10, color=(1, 0, 0))
 
 fv.createMesh(
     "mug", "assets/mug_plastoc.obj", utils.make_pose([0.1, 0, 0], [0, 0, 0]), scale=0.01
 )
 
-# Points
-for i in range(10):
-    for j in range(10):
-        for z in range(10):
-            fv.pushPoint("a", [i * 0.1, j * 0.1, z * 0.1])
+# # Points
+# for i in range(10):
+#     for j in range(10):
+#         for z in range(10):
+#             fv.pushPoint("a", [i * 0.1, j * 0.1, z * 0.1])
 
 # An infinite loop is needed to keep the viewer thread alive.
 while True:
